@@ -1,25 +1,25 @@
 # Copyright (c) 2009, Andrew McNabb
 # Copyright (c) 2003-2008, Brent N. Chun
 
-def with_color(str, fg, bg=49):
+def with_color(string, fg, bg=49):
     '''Given foreground/background ANSI color codes, return a string that,
     when printed, will format the supplied string using the supplied colors.
     '''
-    return "\x1b[%dm\x1b[%dm%s\x1b[39m\x1b[49m" % (fg,bg,str)
+    return "\x1b[%dm\x1b[%dm%s\x1b[39m\x1b[49m" % (fg, bg, string)
 
-def B(str):
+def B(string):
     '''Returns a string that, when printed, will display the supplied string
     in ANSI bold.
     '''
-    return "\x1b[1m%s\x1b[22m" % str
+    return "\x1b[1m%s\x1b[22m" % string
 
-def r(str): return with_color(str, 31) # Red
-def g(str): return with_color(str, 32) # Green
-def y(str): return with_color(str, 33) # Yellow
-def b(str): return with_color(str, 34) # Blue
-def m(str): return with_color(str, 35) # Magenta
-def c(str): return with_color(str, 36) # Cyan
-def w(str): return with_color(str, 37) # White
+def r(string): return with_color(string, 31) # Red
+def g(string): return with_color(string, 32) # Green
+def y(string): return with_color(string, 33) # Yellow
+def b(string): return with_color(string, 34) # Blue
+def m(string): return with_color(string, 35) # Magenta
+def c(string): return with_color(string, 36) # Cyan
+def w(string): return with_color(string, 37) # White
 
 #following from Python cookbook, #475186
 def has_colors(stream):
